@@ -4,6 +4,7 @@
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
  * Copyright (C) 2018-2019 Marek Kasik <mkasik@redhat.com>
  * Copyright (C) 2019 Masamichi Hosoda <trueroad@trueroad.jp>
+ * Copyright (C) 2019, Oliver Sander <oliver.sander@tu-dresden.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +25,8 @@
 #include <string.h>
 
 #ifndef __GI_SCANNER__
+#include <memory>
+
 #include <splash/SplashBitmap.h>
 #include <DateInfo.h>
 #include <GlobalParams.h>
@@ -189,7 +192,7 @@ poppler_document_new_from_file (const char  *uri,
   char *filename;
 
   if (!globalParams) {
-    globalParams = new GlobalParams();
+    globalParams = std::make_unique<GlobalParams>();
   }
 
   filename = g_filename_from_uri (uri, nullptr, error);
@@ -234,6 +237,9 @@ poppler_document_new_from_file (const char  *uri,
  * Creates a new #PopplerDocument.  If %NULL is returned, then @error will be
  * set. Possible errors include those in the #POPPLER_ERROR and #G_FILE_ERROR
  * domains.
+ *
+ * Note that @data must remain valid for as long as the returned document exists.
+ * Prefer using poppler_document_new_from_bytes().
  * 
  * Return value: A newly created #PopplerDocument, or %NULL
  **/
@@ -248,7 +254,7 @@ poppler_document_new_from_data (char        *data,
   GooString *password_g;
 
   if (!globalParams) {
-    globalParams = new GlobalParams();
+    globalParams = std::make_unique<GlobalParams>();
   }
   
   // create stream
@@ -261,6 +267,60 @@ poppler_document_new_from_data (char        *data,
   return _poppler_document_new_from_pdfdoc (newDoc, error);
 }
 
+class BytesStream : public MemStream
+{
+  std::unique_ptr<GBytes, decltype(&g_bytes_unref)> m_bytes;
+
+public:
+  BytesStream(GBytes *bytes, Object &&dictA)
+    : MemStream(static_cast<const char*>(g_bytes_get_data(bytes, nullptr)),
+		0, g_bytes_get_size(bytes), std::move(dictA)),
+      m_bytes{g_bytes_ref(bytes), &g_bytes_unref}
+  { }
+};
+
+/**
+ * poppler_document_new_from_bytes:
+ * @bytes: a #GBytes
+ * @password: (allow-none): password to unlock the file with, or %NULL
+ * @error: (allow-none): Return location for an error, or %NULL
+ *
+ * Creates a new #PopplerDocument from @bytes. The returned document
+ * will hold a reference to @bytes.
+ *
+ * On error,  %NULL is returned, with @error set. Possible errors include
+ * those in the #POPPLER_ERROR and #G_FILE_ERROR domains.
+ *
+ * Return value: (transfer full): a newly created #PopplerDocument, or %NULL
+ *
+ * Since: 0.82
+ **/
+PopplerDocument *
+poppler_document_new_from_bytes (GBytes      *bytes,
+				 const char  *password,
+				 GError     **error)
+{
+  PDFDoc *newDoc;
+  BytesStream *str;
+  GooString *password_g;
+
+  g_return_val_if_fail(bytes != nullptr, nullptr);
+  g_return_val_if_fail(error == nullptr || *error == nullptr, nullptr);
+
+  if (!globalParams) {
+    globalParams = std::make_unique<GlobalParams>();
+  }
+
+  // create stream
+  str = new BytesStream(bytes, Object(objNull));
+
+  password_g = poppler_password_to_latin1(password);
+  newDoc = new PDFDoc(str, password_g, password_g);
+  delete password_g;
+
+  return _poppler_document_new_from_pdfdoc (newDoc, error);
+}
+
 static inline gboolean
 stream_is_memory_buffer_or_local_file (GInputStream *stream)
 {
@@ -301,7 +361,7 @@ poppler_document_new_from_stream (GInputStream *stream,
   g_return_val_if_fail(length == (goffset)-1 || length > 0, NULL);
 
   if (!globalParams) {
-    globalParams = new GlobalParams();
+    globalParams = std::make_unique<GlobalParams>();
   }
 
   if (!G_IS_SEEKABLE(stream) || !g_seekable_can_seek(G_SEEKABLE(stream))) {
@@ -1770,7 +1830,7 @@ poppler_document_get_print_page_ranges (PopplerDocument *document,
 
       *n_ranges = ranges.size ();
       result = g_new (PopplerPageRange, ranges.size ());
-      for (guint i = 0; i < ranges.size (); ++i) {
+      for (size_t i = 0; i < ranges.size (); ++i) {
         result[i].start_page = ranges[i].first;
         result[i].end_page = ranges[i].second;
       }
@@ -2659,7 +2719,7 @@ poppler_index_iter_free (PopplerIndexIter *iter)
 
 struct _PopplerFontsIter
 {
-	std::vector<FontInfo*> *items;
+	std::vector<FontInfo*> items;
 	int index;
 };
 
@@ -2678,10 +2738,10 @@ POPPLER_DEFINE_BOXED_TYPE (PopplerFontsIter, poppler_fonts_iter,
 const char *
 poppler_fonts_iter_get_full_name (PopplerFontsIter *iter)
 {
-	GooString *name;
+	const GooString *name;
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	name = info->getName();
 	if (name != nullptr) {
@@ -2706,7 +2766,7 @@ poppler_fonts_iter_get_name (PopplerFontsIter *iter)
 	const char *name;
 
 	name = poppler_fonts_iter_get_full_name (iter);
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	if (info->getSubset() && name) {
 		while (*name && *name != '+')
@@ -2733,10 +2793,10 @@ poppler_fonts_iter_get_name (PopplerFontsIter *iter)
 const char *
 poppler_fonts_iter_get_substitute_name (PopplerFontsIter *iter)
 {
-	GooString *name;
+	const GooString *name;
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	name = info->getSubstituteName();
 	if (name != nullptr) {
@@ -2758,10 +2818,10 @@ poppler_fonts_iter_get_substitute_name (PopplerFontsIter *iter)
 const char *
 poppler_fonts_iter_get_file_name (PopplerFontsIter *iter)
 {
-	GooString *file;
+	const GooString *file;
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	file = info->getFile();
 	if (file != nullptr) {
@@ -2786,7 +2846,7 @@ poppler_fonts_iter_get_font_type (PopplerFontsIter *iter)
 
 	g_return_val_if_fail (iter != nullptr, POPPLER_FONT_TYPE_UNKNOWN);
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	return (PopplerFontType)info->getType ();
 }
@@ -2804,10 +2864,10 @@ poppler_fonts_iter_get_font_type (PopplerFontsIter *iter)
 const char *
 poppler_fonts_iter_get_encoding (PopplerFontsIter *iter)
 {
-	GooString *encoding;
+	const GooString *encoding;
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	encoding = info->getEncoding();
 	if (encoding != nullptr) {
@@ -2830,7 +2890,7 @@ poppler_fonts_iter_is_embedded (PopplerFontsIter *iter)
 {
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	return info->getEmbedded();
 }
@@ -2848,7 +2908,7 @@ poppler_fonts_iter_is_subset (PopplerFontsIter *iter)
 {
 	FontInfo *info;
 
-	info = (*iter->items)[iter->index];
+	info = iter->items[iter->index];
 
 	return info->getSubset();
 }
@@ -2867,7 +2927,7 @@ poppler_fonts_iter_next (PopplerFontsIter *iter)
 	g_return_val_if_fail (iter != nullptr, FALSE);
 
 	iter->index++;
-	if (iter->index >= (int)iter->items->size())
+	if (iter->index >= (int)iter->items.size())
 		return FALSE;
 
 	return TRUE;
@@ -2890,10 +2950,10 @@ poppler_fonts_iter_copy (PopplerFontsIter *iter)
 
 	new_iter = g_slice_dup (PopplerFontsIter, iter);
 
-	new_iter->items = new std::vector<FontInfo*> ();
-	for (std::size_t i = 0; i < iter->items->size(); i++) {
-		FontInfo *info = (*iter->items)[i];
-		new_iter->items->push_back (new FontInfo (*info));
+	new_iter->items.resize(iter->items.size());
+	for (std::size_t i = 0; i < iter->items.size(); i++) {
+		FontInfo *info = iter->items[i];
+		new_iter->items[i] = new FontInfo (*info);
 	}
 
 	return new_iter;
@@ -2911,21 +2971,21 @@ poppler_fonts_iter_free (PopplerFontsIter *iter)
 	if (G_UNLIKELY (iter == nullptr))
 		return;
 
-        for (auto entry : *iter->items) {
+        for (auto entry : iter->items) {
           delete entry;
         }
-        delete iter->items;
+        iter->items.~vector<FontInfo*>();
 
 	g_slice_free (PopplerFontsIter, iter);
 }
 
 static PopplerFontsIter *
-poppler_fonts_iter_new (std::vector<FontInfo*> *items)
+poppler_fonts_iter_new (std::vector<FontInfo*> &&items)
 {
 	PopplerFontsIter *iter;
 
 	iter = g_slice_new (PopplerFontsIter);
-	iter->items = items;
+	new ((void*)&iter->items) std::vector<FontInfo*>(std::move(items));
 	iter->index = 0;
 
 	return iter;
@@ -3024,22 +3084,18 @@ poppler_font_info_scan (PopplerFontInfo   *font_info,
 			int                n_pages,
 			PopplerFontsIter **iter)
 {
-	std::vector<FontInfo*> *items;
-
 	g_return_val_if_fail (iter != nullptr, FALSE);
 
-	items = font_info->scanner->scan(n_pages);
+	std::vector<FontInfo*> items = font_info->scanner->scan(n_pages);
 
-	if (items == nullptr) {
+	if (items.empty()) {
 		*iter = nullptr;
-	} else if (items->empty()) {
-		*iter = nullptr;
-		delete items;
+		return FALSE;
 	} else {
-		*iter = poppler_fonts_iter_new(items);
+		*iter = poppler_fonts_iter_new(std::move(items));
 	}
 	
-	return (items != nullptr);
+	return TRUE;
 }
 
 /* For backward compatibility */
