@@ -14,10 +14,11 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2008 Koji Otani <sho@bbr.jp>
-// Copyright (C) 2008, 2009, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2009, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2013 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 LE GARREC Vincent <legarrec.vincent@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -321,7 +322,7 @@ CMap::CMap(GooString *collectionA, GooString *cMapNameA, int wModeA) {
   refCnt = 1;
 }
 
-void CMap::useCMap(CMapCache *cache, char *useName) {
+void CMap::useCMap(CMapCache *cache, const char *useName) {
   GooString *useNameStr;
   CMap *subCMap;
 
@@ -391,6 +392,10 @@ void CMap::addCIDs(unsigned int start, unsigned int end, unsigned int nBytes, CI
   int byte;
   unsigned int i, j;
 
+  if (nBytes > 4) {
+    error(errSyntaxError, -1, "Illegal entry in cidchar block in CMap");
+    return;
+  }
   vec = vector;
   for (i = nBytes - 1; i >= 1; --i) {
     byte = (start >> (8 * i)) & 0xff;
