@@ -6,7 +6,7 @@
 //
 // Copyright 2005 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright 2005 Martin Kretzschmar <martink@gnome.org>
-// Copyright 2005-2007, 2009-2011, 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright 2005-2007, 2009-2011, 2017, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2010 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright 2011 Daiki Ueno <ueno@unixuser.org>
 // Copyright 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
@@ -57,7 +57,7 @@ public:
 
   DCTStream(Stream *strA, int colorXformA, Dict *dict, int recursion);
   ~DCTStream();
-  StreamKind getKind() override { return strDCT; }
+  StreamKind getKind() const override { return strDCT; }
   void reset() override;
   int getChar() override;
   int lookChar() override;
@@ -68,7 +68,7 @@ private:
   void init();
 
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 
   int colorXform;
   JSAMPLE *current;
