@@ -3,6 +3,7 @@
 // FlateStream.h
 //
 // Copyright (C) 2005, Jeff Muizelaar <jeff@infidigm.net>
+// Copyright (C) 2010, 2011, 2019, Albert Astals Cid <aacid@kde.org>
 //
 // This file is under the GPLv2 or later license
 //
@@ -10,17 +11,8 @@
 
 #ifndef FLATESTREAM_H
 #define FLATESTREAM_H
-#include <config.h>
-
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
-
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
 
+#include "poppler-config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -31,7 +23,6 @@
 #include <ctype.h>
 #include "goo/gmem.h"
 #include "goo/gfile.h"
-#include "poppler-config.h"
 #include "Error.h"
 #include "Object.h"
 #include "Decrypt.h"
@@ -46,15 +37,23 @@ public:
 
   FlateStream(Stream *strA, int predictor, int columns, int colors, int bits);
   virtual ~FlateStream();
-  virtual StreamKind getKind() { return strFlate; }
-  virtual void reset();
-  virtual int getChar();
-  virtual int lookChar();
-  virtual int getRawChar();
-  virtual GooString *getPSFilter(int psLevel, char *indent);
-  virtual GBool isBinary(GBool last = gTrue);
+  StreamKind getKind() const override { return strFlate; }
+  void reset() override;
+  int getChar() override;
+  int lookChar() override;
+  int getRawChar() override;
+  void getRawChars(int nChars, int *buffer) override;
+  GooString *getPSFilter(int psLevel, const char *indent) override;
+  bool isBinary(bool last = true) override;
 
 private:
+  inline int doGetRawChar() {
+    if (fill_buffer())
+      return EOF;
+
+    return out_buf[out_pos++];
+  }
+
   int fill_buffer(void);
   z_stream d_stream;
   StreamPredictor *pred;
