@@ -233,7 +233,7 @@ GfxFont *GfxFont::makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict
   return font;
 }
 
-GfxFont::GfxFont(const char *tagA, Ref idA, GooString *nameA,
+GfxFont::GfxFont(const char *tagA, Ref idA, const GooString *nameA,
 		 GfxFontType typeA, Ref embFontIDA) {
   ok = false;
   tag = new GooString(tagA);
@@ -759,7 +759,7 @@ GfxFontLoc *GfxFont::locateFont(XRef *xref, PSOutputDev *ps) {
   return nullptr;
 }
 
-GfxFontLoc *GfxFont::locateBase14Font(GooString *base14Name) {
+GfxFontLoc *GfxFont::locateBase14Font(const GooString *base14Name) {
   GooString *path;
 
   path = globalParams->findFontFile(base14Name);
@@ -1530,7 +1530,7 @@ static int parseCharName(char *charName, Unicode *uBuf, int uLen,
 }
 
 int Gfx8BitFont::getNextChar(const char *s, int len, CharCode *code,
-			     Unicode **u, int *uLen,
+			     Unicode const **u, int *uLen,
 			     double *dx, double *dy, double *ox, double *oy) const {
   CharCode c;
 
@@ -1638,7 +1638,7 @@ int *Gfx8BitFont::getCodeToGIDMap(FoFiTrueType *ff) {
 
   // map Unicode through the cmap
   } else if (useUnicode) {
-    Unicode *uAux;
+    const Unicode *uAux;
     for (i = 0; i < 256; ++i) {
       if (((charName = enc[i]) && (u = globalParams->mapNameToUnicodeAll(charName))))
 	map[i] = ff->mapCodeToGID(cmap, u);
@@ -1796,8 +1796,8 @@ GfxCIDFont::GfxCIDFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA,
 	  "Adobe-Japan2",
 	  "Adobe-Korea1",
 	};
-	for (size_t i = 0; i < sizeof(knownCollections)/sizeof(knownCollections[0]); i++) {
-	  if (collection->cmp(knownCollections[i]) == 0) {
+	for (const char *knownCollection : knownCollections) {
+	  if (collection->cmp(knownCollection) == 0) {
 	    error(errSyntaxError, -1, "Missing language pack for '{0:t}' mapping", collection);
 	    return;
 	  }
@@ -2006,7 +2006,7 @@ GfxCIDFont::~GfxCIDFont() {
 }
 
 int GfxCIDFont::getNextChar(const char *s, int len, CharCode *code,
-			    Unicode **u, int *uLen,
+			    Unicode const **u, int *uLen,
 			    double *dx, double *dy, double *ox, double *oy) const {
   CID cid;
   CharCode dummy;
@@ -2183,7 +2183,6 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *mapsizep) {
   Unicode *vumap = nullptr;
   Unicode *tumap = nullptr;
   int *codeToGID = nullptr;
-  unsigned long n;
   int i;
   unsigned long code;
   int wmode;
@@ -2231,7 +2230,7 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *mapsizep) {
       break;
     }
   }
-  n = 65536;
+  const unsigned int n = 65536;
   tumap = new Unicode[n];
   humap = new Unicode[n*N_UCS_CANDIDATES];
   memset(humap,0,sizeof(Unicode)*n*N_UCS_CANDIDATES);
@@ -2243,7 +2242,7 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *mapsizep) {
       CharCode cid;
       for (cid = 0;cid < n ;cid++) {
 	int len;
-	Unicode *ucodes;
+	const Unicode *ucodes;
 
 	len = tctu->mapToUnicode(cid,&ucodes);
 	if (len == 1) {
@@ -2278,7 +2277,7 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *mapsizep) {
     if (ctu) {
       CharCode cid;
       for (cid = 0;cid < n ;cid++) {
-	Unicode *ucode;
+	const Unicode *ucode;
 
 	if (ctu->mapToUnicode(cid, &ucode))
 	  humap[cid*N_UCS_CANDIDATES] = ucode[0];
