@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2008, 2015, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2008, 2015, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
@@ -33,7 +33,6 @@
 #ifndef GFXFONT_H
 #define GFXFONT_H
 
-#include "goo/gtypes.h"
 #include "goo/GooString.h"
 #include "Object.h"
 #include "CharTypes.h"
@@ -174,7 +173,7 @@ public:
   // Build a GfxFont object.
   static GfxFont *makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict);
 
-  GfxFont(const char *tagA, Ref idA, GooString *nameA,
+  GfxFont(const char *tagA, Ref idA, const GooString *nameA,
 	  GfxFontType typeA, Ref embFontIDA);
 
   GfxFont(const GfxFont &) = delete;
@@ -214,13 +213,13 @@ public:
   // Get embedded font ID, i.e., a ref for the font file stream.
   // Returns false if there is no embedded font.
   bool getEmbeddedFontID(Ref *embID) const
-    { *embID = embFontID; return embFontID.num >= 0; }
+    { *embID = embFontID; return embFontID != Ref::INVALID(); }
 
   // Invalidate an embedded font
   // Returns false if there is no embedded font.
   bool invalidateEmbeddedFont() {
-    if (embFontID.num >= 0) {
-      embFontID.num = -1;
+    if (embFontID != Ref::INVALID()) {
+      embFontID = Ref::INVALID();
       return true;
     }
     return false;
@@ -259,7 +258,7 @@ public:
   GfxFontLoc *locateFont(XRef *xref, PSOutputDev *ps);
 
   // Locate a Base-14 font file for a specified font name.
-  static GfxFontLoc *locateBase14Font(GooString *base14Name);
+  static GfxFontLoc *locateBase14Font(const GooString *base14Name);
 
   // Read an external or embedded font file into a buffer.
   char *readEmbFontFile(XRef *xref, int *len);
@@ -271,7 +270,7 @@ public:
   // the number actually used.  Returns the number of bytes used by
   // the char code.
   virtual int getNextChar(const char *s, int len, CharCode *code,
-			  Unicode **u, int *uLen,
+			  Unicode const **u, int *uLen,
 			  double *dx, double *dy, double *ox, double *oy) const = 0;
 
   // Does this font have a toUnicode map?
@@ -297,7 +296,7 @@ protected:
 
   GooString *tag;			// PDF font tag
   Ref id;			// reference (used as unique ID)
-  GooString *name;		// font name
+  const GooString *name;		// font name
   GooString *family;		// font family
   Stretch stretch;			// font stretch
   Weight weight;			// font weight
@@ -327,7 +326,7 @@ public:
 	      GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
 
   int getNextChar(const char *s, int len, CharCode *code,
-			  Unicode **u, int *uLen,
+			  Unicode const **u, int *uLen,
 			  double *dx, double *dy, double *ox, double *oy) const override;
 
   // Return the encoding.
@@ -346,7 +345,7 @@ public:
   bool getUsesMacRomanEnc() const { return usesMacRomanEnc; }
 
   // Get width of a character.
-  double getWidth(Guchar c) const { return widths[c]; }
+  double getWidth(unsigned char c) const { return widths[c]; }
 
   // Return a char code-to-GID mapping for the provided font file.
   // (This is only useful for TrueType fonts.)
@@ -392,7 +391,7 @@ public:
   bool isCIDFont() const override { return true; }
 
   int getNextChar(const char *s, int len, CharCode *code,
-			  Unicode **u, int *uLen,
+			  Unicode const **u, int *uLen,
 			  double *dx, double *dy, double *ox, double *oy) const override;
 
   // Return the writing mode (0=horizontal, 1=vertical).
@@ -457,7 +456,7 @@ public:
 private:
 
   int hashFontObject(Object *obj);
-  void hashFontObject1(Object *obj, FNVHash *h);
+  void hashFontObject1(const Object *obj, FNVHash *h);
 
   GfxFont **fonts;		// list of fonts
   int numFonts;			// number of fonts
