@@ -27,6 +27,7 @@
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2013 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -39,15 +40,15 @@
 #include <assert.h>
 #include "poppler-config.h"
 #include <stdio.h>
-#include "goo/gtypes.h"
 #include "CharTypes.h"
 #include "UnicodeMap.h"
 #include <unordered_map>
 #include <string>
+#include <memory>
 #include <mutex>
+#include <vector>
 
 class GooString;
-class GooList;
 class NameToCharCode;
 class CharCodeToUnicode;
 class CharCodeToUnicodeCache;
@@ -63,7 +64,7 @@ class SysFontList;
 //------------------------------------------------------------------------
 
 // The global parameters object.
-extern GlobalParams *globalParams;
+extern std::unique_ptr<GlobalParams> globalParams;
 
 //------------------------------------------------------------------------
 
@@ -146,7 +147,7 @@ public:
   CMap *getCMap(const GooString *collection, GooString *cMapName, Stream *stream = nullptr);
   UnicodeMap *getTextEncoding();
 
-  GooList *getEncodingNames();
+  std::vector<GooString*> *getEncodingNames();
 
   //----- functions to set parameters
   void addFontFile(GooString *fontName, GooString *path);
@@ -196,7 +197,7 @@ private:
   std::unordered_map<std::string, std::string> unicodeMaps;
   // list of CMap dirs, indexed by collection
   std::unordered_multimap<std::string, std::string> cMapDirs;
-  GooList *toUnicodeDirs;		// list of ToUnicode CMap dirs [GooString]
+  std::vector<GooString*> *toUnicodeDirs;		// list of ToUnicode CMap dirs
   bool baseFontsInitialized;
 #ifdef _WIN32
   // windows font substitutes (for CID fonts)
