@@ -16,6 +16,9 @@
 // Copyright (C) 2009 David Benjamin <davidben@mit.edu>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2015 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2019 Volker Krause <vkrause@kde.org>
+// Copyright (C) 2019 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -28,7 +31,6 @@
 #include "Object.h"
 #include "Stream.h"
 
-class GooList;
 class JBIG2Segment;
 class JBIG2Bitmap;
 class JArithmeticDecoder;
@@ -44,7 +46,7 @@ public:
 
   JBIG2Stream(Stream *strA, Object &&globalsStreamA, Object *globalsStreamRefA);
   ~JBIG2Stream();
-  StreamKind getKind() override { return strJBIG2; }
+  StreamKind getKind() const override { return strJBIG2; }
   void reset() override;
   void close() override;
   Goffset getPos() override;
@@ -70,20 +72,20 @@ private:
 			      unsigned int numInstances,
 			      unsigned int logStrips,
 			      int numSyms,
-			      JBIG2HuffmanTable *symCodeTab,
+			      const JBIG2HuffmanTable *symCodeTab,
 			      unsigned int symCodeLen,
 			      JBIG2Bitmap **syms,
 			      unsigned int defPixel, unsigned int combOp,
 			      unsigned int transposed, unsigned int refCorner,
 			      int sOffset,
-			      JBIG2HuffmanTable *huffFSTable,
-			      JBIG2HuffmanTable *huffDSTable,
-			      JBIG2HuffmanTable *huffDTTable,
-			      JBIG2HuffmanTable *huffRDWTable,
-			      JBIG2HuffmanTable *huffRDHTable,
-			      JBIG2HuffmanTable *huffRDXTable,
-			      JBIG2HuffmanTable *huffRDYTable,
-			      JBIG2HuffmanTable *huffRSizeTable,
+			      const JBIG2HuffmanTable *huffFSTable,
+			      const JBIG2HuffmanTable *huffDSTable,
+			      const JBIG2HuffmanTable *huffDTTable,
+			      const JBIG2HuffmanTable *huffRDWTable,
+			      const JBIG2HuffmanTable *huffRDHTable,
+			      const JBIG2HuffmanTable *huffRDXTable,
+			      const JBIG2HuffmanTable *huffRDYTable,
+			      const JBIG2HuffmanTable *huffRSizeTable,
 			      unsigned int templ,
 			      int *atx, int *aty);
   void readPatternDictSeg(unsigned int segNum, unsigned int length);
@@ -134,8 +136,8 @@ private:
   unsigned int pageDefPixel;
   JBIG2Bitmap *pageBitmap;
   unsigned int defCombOp;
-  GooList *segments;		// [JBIG2Segment]
-  GooList *globalSegments;	// [JBIG2Segment]
+  std::vector<JBIG2Segment*> *segments;
+  std::vector<JBIG2Segment*> *globalSegments;
   Stream *curStr;
   unsigned char *dataPtr;
   unsigned char *dataEnd;
