@@ -4,7 +4,7 @@
 //
 // A JPX stream decoder using OpenJPEG
 //
-// Copyright 2008, 2010 Albert Astals Cid <aacid@kde.org>
+// Copyright 2008, 2010, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2011 Daniel Glöckner <daniel-gl@gmx.net>
 // Copyright 2013, 2014 Adrian Johnson <ajohnson@redneon.com>
 // Copyright 2015 Adam Reichold <adam.reichold@t-online.de>
@@ -18,7 +18,6 @@
 #define JPEG2000STREAM_H
 
 #include "config.h"
-#include "goo/gtypes.h"
 #include "Object.h"
 #include "Stream.h"
 
@@ -29,7 +28,7 @@ public:
 
   JPXStream(Stream *strA);
   ~JPXStream();
-  StreamKind getKind() override { return strJPX; }
+  StreamKind getKind() const override { return strJPX; }
   void reset() override;
   void close() override;
   Goffset getPos() override;
@@ -39,7 +38,7 @@ public:
   bool isBinary(bool last = true) override;
   void getImageParams(int *bitsPerComponent, StreamColorSpaceMode *csMode) override;
 
-  int readStream(int nChars, Guchar *buffer) {
+  int readStream(int nChars, unsigned char *buffer) {
     return str->doGetChars(nChars, buffer);
   }
 private:
@@ -49,7 +48,7 @@ private:
 
   void init();
   bool hasGetChars() override { return true; }
-  int getChars(int nChars, Guchar *buffer) override;
+  int getChars(int nChars, unsigned char *buffer) override;
 };
 
 #endif
