@@ -698,15 +698,14 @@ void ArthurOutputDev::updateFont(GfxState *state)
   }
 }
 
-static QPainterPath convertPath(GfxState *state, GfxPath *path, Qt::FillRule fillRule)
+static QPainterPath convertPath(GfxState *state, const GfxPath *path, Qt::FillRule fillRule)
 {
-  GfxSubpath *subpath;
   int i, j;
 
   QPainterPath qPath;
   qPath.setFillRule(fillRule);
   for (i = 0; i < path->getNumSubpaths(); ++i) {
-    subpath = path->getSubpath(i);
+    const GfxSubpath *subpath = path->getSubpath(i);
     if (subpath->getNumPoints() > 0) {
       qPath.moveTo(subpath->getX(0), subpath->getY(0));
       j = 1;
@@ -882,7 +881,7 @@ void ArthurOutputDev::eoClip(GfxState *state)
 void ArthurOutputDev::drawChar(GfxState *state, double x, double y,
 			       double dx, double dy,
 			       double originX, double originY,
-			       CharCode code, int nBytes, Unicode *u, int uLen) {
+			       CharCode code, int nBytes, const Unicode *u, int uLen) {
 
   // First handle type3 fonts
   GfxFont *gfxFont = state->getFont();
@@ -1054,7 +1053,7 @@ void ArthurOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
 void ArthurOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
 				int width, int height,
 				GfxImageColorMap *colorMap,
-				bool interpolate, int *maskColors, bool inlineImg)
+				bool interpolate, const int *maskColors, bool inlineImg)
 {
   unsigned int *data;
   unsigned int *line;
