@@ -249,7 +249,7 @@ namespace Debug {
         if ( count == 0 )
         {
             utf8Map = nullptr;
-            delete globalParams;
+            globalParams.reset();
         }
       }
     
@@ -265,7 +265,7 @@ namespace Debug {
         if ( count == 0 )
         {
             utf8Map = nullptr;
-            globalParams = new GlobalParams();
+            globalParams = std::make_unique<GlobalParams>();
             setErrorCallback(qt5ErrorFunction, nullptr);
         }
         count ++;
@@ -304,9 +304,14 @@ namespace Debug {
         }
     }
 
-    FormFieldIconData POPPLER_QT5_EXPORT *FormFieldIconData::getData( const FormFieldIcon &f )
+    FormWidget *FormFieldData::getFormWidget( const FormField *f )
+    {
+        return f->m_formData->fm;
+    }
+
+    FormFieldIconData *FormFieldIconData::getData( const FormFieldIcon &f )
     {
         return f.d_ptr;
     }
 
-}
\ No newline at end of file
+}
