@@ -934,10 +934,10 @@ static void RenderPdf(const char *fileName)
 
         SplashBitmap *bmpSplash = nullptr;
 
-        GooTimer msTimer;
+        GooTimer msRenderTimer;
         bmpSplash = engineSplash->renderBitmap(curPage, 100.0, 0);
-        msTimer.stop();
-        double timeInMs = msTimer.getElapsed();
+        msRenderTimer.stop();
+        timeInMs = msRenderTimer.getElapsed();
         if (gfTimings) {
             if (!bmpSplash)
                 LogInfo("page splash %d: failed to render\n", curPage);
@@ -1237,7 +1237,7 @@ int main(int argc, char **argv)
     assert(gArgsListRoot);
 
     SplashColorsInit();
-    globalParams = new GlobalParams();
+    globalParams = std::make_unique<GlobalParams>();
     if (!globalParams)
         return 1;
     globalParams->setErrQuiet(false);
@@ -1270,7 +1270,6 @@ int main(int argc, char **argv)
         fclose(outFile);
     PreviewBitmapDestroy();
     StrList_Destroy(&gArgsListRoot);
-    delete globalParams;
     free(gOutFileName);
     return 0;
 }
