@@ -18,6 +18,7 @@
 // Copyright (C) 2014, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -27,9 +28,7 @@
 #include "config.h"
 #include <poppler-config.h>
 #include <stdio.h>
-#include "goo/gtypes.h"
 #include "goo/gmem.h"
-#include "goo/GooList.h"
 #include "parseargs.h"
 #include "Annot.h"
 #include "GlobalParams.h"
@@ -92,7 +91,7 @@ int main(int argc, char *argv[]) {
   char *p;
   bool ok;
   int exitCode;
-  GooList *embeddedFiles = nullptr;
+  std::vector<FileSpec*> embeddedFiles;
   int nFiles, nPages, n, i, j;
   FileSpec *fileSpec;
   Page *page;
@@ -124,7 +123,7 @@ int main(int argc, char *argv[]) {
   fileName = new GooString(argv[1]);
 
   // read config file
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
   if (textEncName[0]) {
     globalParams->setTextEncoding(textEncName);
   }
@@ -133,7 +132,7 @@ int main(int argc, char *argv[]) {
   if (!(uMap = globalParams->getTextEncoding())) {
     error(errConfig, -1, "Couldn't get text encoding");
     delete fileName;
-    goto err1;
+    goto err0;
   }
 
   // open PDF file
@@ -161,9 +160,8 @@ int main(int argc, char *argv[]) {
     goto err2;
   }
 
-  embeddedFiles = new GooList();
   for (i = 0; i < doc->getCatalog()->numEmbeddedFiles(); ++i)
-    embeddedFiles->push_back(doc->getCatalog()->embeddedFile(i));
+    embeddedFiles.push_back(doc->getCatalog()->embeddedFile(i));
 
   nPages = doc->getCatalog()->getNumPages();
   for (i = 0; i < nPages; ++i) {
@@ -178,17 +176,17 @@ int main(int argc, char *argv[]) {
       annot = annots->getAnnot(j);
       if (annot->getType() != Annot::typeFileAttachment)
         continue;
-      embeddedFiles->push_back(new FileSpec(static_cast<AnnotFileAttachment *>(annot)->getFile()));
+      embeddedFiles.push_back(new FileSpec(static_cast<AnnotFileAttachment *>(annot)->getFile()));
     }
   }
 
-  nFiles = embeddedFiles->getLength();
+  nFiles = embeddedFiles.size();
 
   // list embedded files
   if (doList) {
     printf("%d embedded files\n", nFiles);
     for (i = 0; i < nFiles; ++i) {
-      fileSpec = static_cast<FileSpec *>(embeddedFiles->get(i));
+      fileSpec = embeddedFiles[i];
       printf("%d: ", i+1);
       s1 = fileSpec->getFileName();
       if (!s1) {
@@ -219,7 +217,7 @@ int main(int argc, char *argv[]) {
   // save all embedded files
   } else if (saveAll) {
     for (i = 0; i < nFiles; ++i) {
-      fileSpec = static_cast<FileSpec *>(embeddedFiles->get(i));
+      fileSpec = embeddedFiles[i];
       if (savePath[0]) {
 	n = strlen(savePath);
 	if (n > (int)sizeof(path) - 2) {
@@ -278,7 +276,7 @@ int main(int argc, char *argv[]) {
       goto err2;
     }
 
-    fileSpec = static_cast<FileSpec *>(embeddedFiles->get(saveNum - 1));
+    fileSpec = embeddedFiles[saveNum - 1];
     if (savePath[0]) {
       p = savePath;
     } else {
@@ -329,12 +327,10 @@ int main(int argc, char *argv[]) {
 
   // clean up
  err2:
-  if (embeddedFiles)
-    deleteGooList<FileSpec>(embeddedFiles);
+  for (auto& file : embeddedFiles)
+    delete file;
   uMap->decRefCnt();
   delete doc;
- err1:
-  delete globalParams;
  err0:
 
   return exitCode;
