@@ -25,6 +25,8 @@
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2018 Evangelos Rigas <erigas@rnd2.org>
+// Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -867,11 +869,10 @@ int main(int argc, char *argv[]) {
     printStructure = true;
 
   // read config file
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
 
   if (printEnc) {
     printEncodings();
-    delete globalParams;
     exitCode = 0;
     goto err0;
   }
@@ -964,11 +965,7 @@ int main(int argc, char *argv[]) {
     // print info
     long long filesize = 0;
 
-#ifdef VMS
-    f = fopen(fileName->c_str(), "rb", "ctx=stm");
-#else
     f = fopen(fileName->c_str(), "rb");
-#endif
     if (f) {
       Gfseek(f, 0, SEEK_END);
       filesize = Gftell(f);
@@ -988,7 +985,6 @@ int main(int argc, char *argv[]) {
   delete doc;
   delete fileName;
  err1:
-  delete globalParams;
  err0:
 
   return exitCode;
