@@ -12,6 +12,7 @@
 // Copyright (C) 2017 Léonard Michelet <leonard.michelet@smile.fr>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 //========================================================================
 #include "config.h"
@@ -168,12 +169,11 @@ main (int argc, char *argv[])
 	exitCode = 0;
       goto err0;
     }
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
   ok = extractPages (argv[1], argv[2]);
   if (ok) {
     exitCode = 0;
   }
-  delete globalParams;
 
 err0:
 
