@@ -12,6 +12,7 @@
 // Copyright 2017, 2019 Adrian Johnson <ajohnson@redneon.com>
 // Copyright 2018 Chinmoy Ranjan Pradhan <chinmoyrp65@protonmail.com>
 // Copyright 2019 Alexey Pavlov <alexpux@gmail.com>
+// Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 //========================================================================
 
@@ -151,7 +152,7 @@ int main(int argc, char *argv[])
   SignatureInfo *sig_info = nullptr;
   char *time_str = nullptr;
   std::vector<FormWidgetSignature*> sig_widgets;
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
 
   Win32Console win32Console(&argc, &argv);
   int exitCode = 99;
@@ -257,13 +258,12 @@ int main(int argc, char *argv[])
              ranges[0], ranges[1], ranges[2], ranges[3]);
       Goffset checked_file_size;
       GooString* signature = sig_widgets.at(i)->getCheckedSignature(&checked_file_size);
-      if (signature && checked_file_size == ranges[3])
-      {
+      if (signature && checked_file_size == ranges[3]) {
         printf("  - Total document signed\n");
-        delete signature;
-      }
-      else
+      } else {
         printf("  - Not total document signed\n");
+      }
+      delete signature;
     }
     printf("  - Signature Validation: %s\n", getReadableSigState(sig_info->getSignatureValStatus()));
     gfree(time_str);
@@ -278,7 +278,6 @@ int main(int argc, char *argv[])
 end:
   delete fileName;
   delete doc;
-  delete globalParams;
 
   return exitCode;
 }
