@@ -18,7 +18,7 @@
 // Copyright (C) 2009 Michael K. Johnson <a1237@danlj.org>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
-// Copyright (C) 2009, 2010, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2010, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010, 2011-2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010, 2014 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2010 Jonathan Liu <net147@gmail.com>
@@ -32,6 +32,7 @@
 // Copyright (C) 2016 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2018 Martin Packman <gzlist@googlemail.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -46,7 +47,6 @@
 #include <string.h>
 #include "parseargs.h"
 #include "goo/gmem.h"
-#include "goo/gtypes.h"
 #include "goo/GooString.h"
 #include "goo/ImgWriter.h"
 #include "goo/JpegWriter.h"
@@ -470,7 +470,7 @@ static void writePageImage(GooString *filename)
   unsigned char *row = (unsigned char *) gmallocn(width, 4);
 
   for (int y = 0; y < height; y++ ) {
-    uint32_t *pixel = (uint32_t *) (data + y*stride);
+    uint32_t *pixel = reinterpret_cast<uint32_t *>((data + y*stride));
     unsigned char *rowp = row;
     int bit = 7;
     for (int x = 0; x < width; x++, pixel++) {
@@ -1080,7 +1080,7 @@ int main(int argc, char *argv[]) {
   if (printdlg)
     printToWin32 = true;
 
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
   if (quiet) {
     globalParams->setErrQuiet(quiet);
   }
@@ -1263,7 +1263,6 @@ int main(int argc, char *argv[]) {
   // clean up
   delete cairoOut;
   delete doc;
-  delete globalParams;
   if (fileName)
     delete fileName;
   if (outputName)
